@@ -3,7 +3,7 @@
 
 # insert the package for universal imports.
 import os, sys
-from fil3s import *
+from dev0s import *
 
 # settings.
 SOURCE_NAME = "netw0rk"
